# eric7.WebBrowser.SpeedDial.Page

Module implementing a structure to hold the data for a speed dial page.

### Global Attributes

None

### Classes

Page | Class to hold the data for a speed dial page.

### Functions

None

## Page

Class to hold the data for a speed dial page.

### Derived from

None

### Class Attributes

None

### Class Methods

None

### Methods

Page | Constructor
__eq__ | Special method implementing the equality operator.
isValid | Public method to check the validity.

### Static Methods

None

#### Page (Constructor)

Page(url="", title="", broken=False)

Constructor

url
  URL of the page (string)
title
  title of the page (string)
broken
  flag indicating a broken connection (boolean)

#### Page.__eq__

__eq__(other)

Special method implementing the equality operator.

other
  reference to the other page object (Page)

Return:
  flag indicating equality (boolean)

#### Page.isValid

isValid()

Public method to check the validity.

Return:
  flag indicating a valid object

Return Type:
  bool

Up